

![image](https://img.shields.io/pypi/v/quantzoo.svg) ![image](https://img.shields.io/travis/Jie-Yuan/quantzoo.svg) ![image](https://readthedocs.org/projects/quantzoo/badge/?version=latest)



<h1 align = "center">🔥QuantZoo🔥</h1>

---
# Install
```python
pip install -U quantzoo
```

# [Docs](https://jie-yuan.github.io/quantzoo/)

# Usages
```
import quantzoo
```

# 个人财富课
![个人财富课](https://tva1.sinaimg.cn/large/e6c9d24egy1h1dum2e0xij20ef0ctdgw.jpg)

# 量化投资系统
![量化投资系统](https://tva1.sinaimg.cn/large/e6c9d24egy1h1dunn77maj20e30aoaa8.jpg)


[投资策略](./投资策略)
---
# TODO
